@@ -1,4 +1,6 @@
 import math
+import matplotlib.pyplot as plt
+import matplotlib.image as mpimg
 
 # Creating Phase I.
 # assuming no air resistance, 
@@ -20,7 +22,7 @@ class Projectile(object):
         self.swivel_angle = swivel_angle
         self.initial_velocity = initial_velocity
     
-    @staticmethod
+    
     def range(self):
         """
         this is the range of the projectile assuming it hits the board at d = 8m. 
@@ -32,7 +34,7 @@ class Projectile(object):
         return  d / (math.cos(self.swivel_angle * k))
     
     
-    @staticmethod
+    
     def height(self):
         """
         this is the distance in the y-direction relative to the bullseye.
@@ -47,7 +49,7 @@ class Projectile(object):
      
         return (math.tan(k*self.tilt_angle)*R_x) - ((g * R_x**2) / (2 * (self.initial_velocity *  math.cos(k*self.tilt_angle))**2 ))   
     
-    @staticmethod
+    
     def shift(self):
                                                  
         """
@@ -65,7 +67,7 @@ class Projectile(object):
             return 0
 
 
-class coordinates(object): 
+class Coordinates(object): 
     ##using constructors instantiate the object which initializes
     ##The data values to the class
     def __init__(self,tilt_angle, swivel_angle, initial_velocity):
@@ -74,7 +76,7 @@ class coordinates(object):
         self.initial_velocity = initial_velocity
 
 
-    @staticmethod
+    
     def cartesian_coordinates(self):
         """
         Returns the cartesian coordinates in relation to the given tilt angle,
@@ -87,7 +89,7 @@ class coordinates(object):
         return [z,y]
 
 
-    @staticmethod
+    
     def theta(self):
         """
         this gives us our theta value used to determine score
@@ -115,7 +117,7 @@ class coordinates(object):
         if z>0 and y<0:
             return 360 - math.atan(abs(y/z)) * (k**-1)
     
-    @staticmethod
+    
     def r(self):
         """
         this gives us our r value used to determine score
@@ -128,19 +130,19 @@ class coordinates(object):
     
         return r 
     
-    @staticmethod
+    
     def polar_coordinates(self):
         """
         this function combines the projectiles and coordinates class to create the r and theta used in the scores class.
         """
 
-        r = coordinates.r(self)
-        theta = coordinates.theta(self)
+        r = Coordinates.r(self)
+        theta = Coordinates.theta(self)
 
         
         return [r, theta]
 
-@staticmethod
+
 def initial_score(theta):
 
     '''
@@ -194,7 +196,7 @@ def initial_score(theta):
         return "error"
         
 
-@staticmethod
+
 def final_score(r, theta):
     
     """
@@ -240,18 +242,37 @@ def final_score(r, theta):
     elif r >= r_6: 
         return  0   
 
-@staticmethod
+
 def dart_simulation(tilt_angle, swivel_angle, initial_velocity):
     
     """
     this function will combine phase I and II's functions in order to calculate the final score. 
     """
-    Coordinates = coordinates(tilt_angle, swivel_angle, initial_velocity)
+    Coordinates_simulation = Coordinates(tilt_angle, swivel_angle, initial_velocity)
     
-    r = Coordinates.r()
-    theta = Coordinates.theta()
+    r = Coordinates_simulation.r()
+    theta = Coordinates_simulation.theta()
     
     if tilt_angle >= 90 or tilt_angle <= -90 or swivel_angle >= 90 or swivel_angle <= -90 or initial_velocity ==0:
         return "null shot, please ensure the tilt and swivel angles are both between -90 and 90, and that the velocity is positive"
     else:
-        return final_score(r, theta)
\ No newline at end of file
+        return final_score(r, theta)  
+
+def display_dartboard(r, theta):
+    """ A function that displays an image of a dartboard with a cross of where the dart hits,
+    if no cross appears it means the shot is out of the 0.243m x 0.243m square"""
+   
+    img = mpimg.imread('dartboard.png') #Reads the png image of the dartboard
+    imgplot = plt.imshow(img, extent = (-0.2478,0.2478,-0.2478,0.2478)) #Displays the image to the figure, extent places the image on  the coordinates stated
+    ax = plt.gca() #Creates an instance to create the axis
+
+    ax.get_xaxis().set_visible(False) #Hides the axis for a better UI
+    ax.get_yaxis().set_visible(False)
+
+    cartesian_coordinate_x = r * math.cos(theta * math.pi / 180)
+    cartesian_coordinate_y = r * math.sin(theta * math.pi / 180)
+
+    plt.xlim([-0.243, 0.243]) #Sets the respective coordinate limits
+    plt.ylim([-0.243, 0.243])
+    plt.plot([cartesian_coordinate_x],[cartesian_coordinate_y], color = "magenta", marker = "x") #Plots an "x" marker on the figure
+    plt.show() #Runs the figure to display it
